@@ -1,7 +1,8 @@
-def command(name, aliases=None, usage=None, description=None, roles=None, ignore_filter=False):
+def command(name, aliases=None, usage=None, description=None, roles=None, ignore_filter=False,has_arts=False):
     def decorator(func):
         setattr(func, '__command__', name)
         setattr(func, '__ignore_filter__', ignore_filter)
+        setattr(func,'has_arts',has_arts)
         if description:
             setattr(func, 'description', description)
         if aliases:
@@ -10,6 +11,7 @@ def command(name, aliases=None, usage=None, description=None, roles=None, ignore
             setattr(func, 'usage', usage)
         if roles:
             setattr(func, 'roles', roles)
+
         return func
 
     return decorator
